@@ -8,16 +8,18 @@ from switchcraft.clients.dynamodb import DynamoDBClient
 from switchcraft.clients.ec2 import EC2Client
 from switchcraft.clients.rds import RDSClient
 from switchcraft.clients.sns import SNSClient
+from switchcraft.clients.s3 import S3Client
 
 
 # Overriding '__all__' to ensure that public access to classes are controlled.
 __all__ = [
     AlbClient,
     ConfigClient,
-    Evaluation,
     ComplianceType,
-    EC2Client,
-    SNSClient,
     DynamoDBClient,
-    RDSClient
+    Evaluation,
+    EC2Client,
+    RDSClient,
+    S3Client,
+    SNSClient
 ]
