@@ -27,4 +27,4 @@ class RDSClient:
         paginator = self.rds.get_paginator('describe_db_instances')
 
         for page in paginator.paginate(**kwargs):
-            yield from page.get('LoadBalancers')
+            yield from page.get('DBInstances')
