@@ -4,6 +4,7 @@ Data Class representing AWS Config Events.
 """
 
 import json
+from typing import Any, Dict, Optional
 
 from switchcraft.data_classes.base import DictWrapper
 
@@ -30,8 +31,23 @@ class ConfigEvent(DictWrapper):
 
     @property
     def invoking_event(self) -> ConfigInvokingEvent:
+        """Returns a ConfigInvokingEvent object.
+
+        This object contains details about the Config event that was
+        invoked.
+        """
         return ConfigInvokingEvent(json.loads(self['invokingEvent']))
 
+    @property
+    def rule_parameters(self) -> Optional[Dict[str, Any]]:
+        """Returns a dictionary containing rule parameters.
+
+        This is an optional field that only gets generated when an AWS
+        Config Rule contains parameters.
+        """
+        rule_parameters = self.get('ruleParameters')
+        return None if rule_parameters is None else json.loads(rule_parameters)
+
     @property
     def result_token(self) -> str:
         """Returns a result token.
@@ -43,6 +59,13 @@ class ConfigEvent(DictWrapper):
 
     @property
     def event_left_scope(self) -> bool:
+        """Indicates if the AWS resource to be evaluated has been removed from
+        the rule's scope.
+
+        If the value is true, the function indicates that the evaluation
+        can be ignored by passing NOT_APPLICABLE as the value for the
+        ComplianceType attribute in the PutEvaluations call.
+        """
         return self['eventLeftScope']
 
     @property
